pub fn evaluate_causal_refuter(
compiled: &CompileOutput,
target_node_id: &str,
max_removed_nodes: usize,
) -> OracleRefutationResultExpand description
Searches for a causal refutation witness that flips support for the target node.
pub fn evaluate_causal_refuter(
compiled: &CompileOutput,
target_node_id: &str,
max_removed_nodes: usize,
) -> OracleRefutationResultSearches for a causal refutation witness that flips support for the target node.