pub struct DeltaParityAssessment {
pub changed_node_ids: Vec<String>,
pub recomputed_node_ids: Vec<String>,
pub recomputed_region_ids: Vec<RegionId>,
pub parity_match: bool,
pub certificate: OracleParityCertificate,
}Fields
changed_node_ids: Vec<String>recomputed_node_ids: Vec<String>recomputed_region_ids: Vec<RegionId>parity_match: boolcertificate: OracleParityCertificateTrait Implementations
Sourceimpl Clone for DeltaParityAssessment
impl Clone for DeltaParityAssessment
Sourcefn clone(&self) -> DeltaParityAssessment
fn clone(&self) -> DeltaParityAssessment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeltaParityAssessment
impl Debug for DeltaParityAssessment
Sourceimpl<'de> Deserialize<'de> for DeltaParityAssessment
impl<'de> Deserialize<'de> for DeltaParityAssessment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeltaParityAssessment
Sourceimpl JsonSchema for DeltaParityAssessment
impl JsonSchema for DeltaParityAssessment
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeltaParityAssessment
impl PartialEq for DeltaParityAssessment
Sourcefn eq(&self, other: &DeltaParityAssessment) -> bool
fn eq(&self, other: &DeltaParityAssessment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DeltaParityAssessment
impl Serialize for DeltaParityAssessment
impl StructuralPartialEq for DeltaParityAssessment