pub struct OracleParityCertificate {
pub slice_id: OracleSliceId,
pub region_ids: Vec<RegionId>,
pub parity_match: bool,
}Fields
slice_id: OracleSliceIdregion_ids: Vec<RegionId>parity_match: boolTrait Implementations
Sourceimpl Clone for OracleParityCertificate
impl Clone for OracleParityCertificate
Sourcefn clone(&self) -> OracleParityCertificate
fn clone(&self) -> OracleParityCertificate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OracleParityCertificate
impl Debug for OracleParityCertificate
Sourceimpl<'de> Deserialize<'de> for OracleParityCertificate
impl<'de> Deserialize<'de> for OracleParityCertificate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OracleParityCertificate
Sourceimpl JsonSchema for OracleParityCertificate
impl JsonSchema for OracleParityCertificate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OracleParityCertificate
impl PartialEq for OracleParityCertificate
Sourcefn eq(&self, other: &OracleParityCertificate) -> bool
fn eq(&self, other: &OracleParityCertificate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OracleParityCertificate
impl Serialize for OracleParityCertificate
impl StructuralPartialEq for OracleParityCertificate