pub struct OracleRefutationResult {
pub mode: RefutationMode,
pub target_node_id: String,
pub baseline_supported: bool,
pub searched_budget: usize,
pub outcome: OracleRefutationOutcome,
}Fields
mode: RefutationModetarget_node_id: Stringbaseline_supported: boolsearched_budget: usizeoutcome: OracleRefutationOutcomeTrait Implementations
Sourceimpl Clone for OracleRefutationResult
impl Clone for OracleRefutationResult
Sourcefn clone(&self) -> OracleRefutationResult
fn clone(&self) -> OracleRefutationResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OracleRefutationResult
impl Debug for OracleRefutationResult
Sourceimpl<'de> Deserialize<'de> for OracleRefutationResult
impl<'de> Deserialize<'de> for OracleRefutationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OracleRefutationResult
Sourceimpl JsonSchema for OracleRefutationResult
impl JsonSchema for OracleRefutationResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OracleRefutationResult
impl PartialEq for OracleRefutationResult
Sourcefn eq(&self, other: &OracleRefutationResult) -> bool
fn eq(&self, other: &OracleRefutationResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OracleRefutationResult
impl Serialize for OracleRefutationResult
impl StructuralPartialEq for OracleRefutationResult