pub struct OracleSliceSelectionPolicy {
pub policy_name: String,
pub prefers_bounded_regions: bool,
pub max_exact_nodes: usize,
}Fields
policy_name: Stringprefers_bounded_regions: boolmax_exact_nodes: usizeTrait Implementations
Sourceimpl Clone for OracleSliceSelectionPolicy
impl Clone for OracleSliceSelectionPolicy
Sourcefn clone(&self) -> OracleSliceSelectionPolicy
fn clone(&self) -> OracleSliceSelectionPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OracleSliceSelectionPolicy
impl Debug for OracleSliceSelectionPolicy
Sourceimpl<'de> Deserialize<'de> for OracleSliceSelectionPolicy
impl<'de> Deserialize<'de> for OracleSliceSelectionPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OracleSliceSelectionPolicy
Sourceimpl JsonSchema for OracleSliceSelectionPolicy
impl JsonSchema for OracleSliceSelectionPolicy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OracleSliceSelectionPolicy
impl PartialEq for OracleSliceSelectionPolicy
Sourcefn eq(&self, other: &OracleSliceSelectionPolicy) -> bool
fn eq(&self, other: &OracleSliceSelectionPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OracleSliceSelectionPolicy