pub struct TemporalReplayAssessment {
pub cutoff_recorded_at: String,
pub selected_recorded_at: String,
pub source_envelope_id: String,
pub graph_hash: ContentDigest,
pub matched_expected_hash: bool,
}Fields
cutoff_recorded_at: Stringselected_recorded_at: Stringsource_envelope_id: Stringgraph_hash: ContentDigestmatched_expected_hash: boolTrait Implementations
Sourceimpl Clone for TemporalReplayAssessment
impl Clone for TemporalReplayAssessment
Sourcefn clone(&self) -> TemporalReplayAssessment
fn clone(&self) -> TemporalReplayAssessment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemporalReplayAssessment
impl Debug for TemporalReplayAssessment
Sourceimpl<'de> Deserialize<'de> for TemporalReplayAssessment
impl<'de> Deserialize<'de> for TemporalReplayAssessment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TemporalReplayAssessment
Sourceimpl JsonSchema for TemporalReplayAssessment
impl JsonSchema for TemporalReplayAssessment
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TemporalReplayAssessment
impl PartialEq for TemporalReplayAssessment
Sourcefn eq(&self, other: &TemporalReplayAssessment) -> bool
fn eq(&self, other: &TemporalReplayAssessment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TemporalReplayAssessment
impl Serialize for TemporalReplayAssessment
impl StructuralPartialEq for TemporalReplayAssessment