pub struct TemporalReplaySnapshot {
pub recorded_at: String,
pub batch: ProjectionImportBatchV3,
}Fields
recorded_at: Stringbatch: ProjectionImportBatchV3Trait Implementations
Sourceimpl Clone for TemporalReplaySnapshot
impl Clone for TemporalReplaySnapshot
Sourcefn clone(&self) -> TemporalReplaySnapshot
fn clone(&self) -> TemporalReplaySnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemporalReplaySnapshot
impl Debug for TemporalReplaySnapshot
Sourceimpl<'de> Deserialize<'de> for TemporalReplaySnapshot
impl<'de> Deserialize<'de> for TemporalReplaySnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemporalReplaySnapshot
impl JsonSchema for TemporalReplaySnapshot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemporalReplaySnapshot
impl RefUnwindSafe for TemporalReplaySnapshot
impl Send for TemporalReplaySnapshot
impl Sync for TemporalReplaySnapshot
impl Unpin for TemporalReplaySnapshot
impl UnsafeUnpin for TemporalReplaySnapshot
impl UnwindSafe for TemporalReplaySnapshot